class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

from QtWidgets import *

import datetime

class QDBusAbstractAdaptor(QObject):
    """"""
    def __init__(self, parent):
        '''void QDBusAbstractAdaptor.__init__(QObject parent)'''
    def autoRelaySignals(self):
        '''bool QDBusAbstractAdaptor.autoRelaySignals()'''
        return bool()
    def setAutoRelaySignals(self, enable):
        '''void QDBusAbstractAdaptor.setAutoRelaySignals(bool enable)'''


class QDBusAbstractInterface(QObject):
    """"""
    def __init__(self, service, path, interface, connection, parent):
        '''void QDBusAbstractInterface.__init__(str service, str path, str interface, QDBusConnection connection, QObject parent)'''
    def disconnectNotify(self, signal):
        '''void QDBusAbstractInterface.disconnectNotify(QMetaMethod signal)'''
    def connectNotify(self, signal):
        '''void QDBusAbstractInterface.connectNotify(QMetaMethod signal)'''
    def asyncCallWithArgumentList(self, method, args):
        '''QDBusPendingCall QDBusAbstractInterface.asyncCallWithArgumentList(str method, list-of-QVariant args)'''
        return QDBusPendingCall()
    def asyncCall(self, method, arg1 = QVariant(), arg2 = QVariant(), arg3 = QVariant(), arg4 = QVariant(), arg5 = QVariant(), arg6 = QVariant(), arg7 = QVariant(), arg8 = QVariant()):
        '''QDBusPendingCall QDBusAbstractInterface.asyncCall(str method, QVariant arg1 = QVariant(), QVariant arg2 = QVariant(), QVariant arg3 = QVariant(), QVariant arg4 = QVariant(), QVariant arg5 = QVariant(), QVariant arg6 = QVariant(), QVariant arg7 = QVariant(), QVariant arg8 = QVariant())'''
        return QDBusPendingCall()
    def callWithCallback(self, method, args, returnMethod, errorMethod):
        '''bool QDBusAbstractInterface.callWithCallback(str method, list-of-QVariant args, slot returnMethod, slot errorMethod)'''
        return bool()
    def callWithCallback(self, method, args, slot):
        '''bool QDBusAbstractInterface.callWithCallback(str method, list-of-QVariant args, slot slot)'''
        return bool()
    def callWithArgumentList(self, mode, method, args):
        '''QDBusMessage QDBusAbstractInterface.callWithArgumentList(QDBus.CallMode mode, str method, list-of-QVariant args)'''
        return QDBusMessage()
    def call(self, method, arg1 = QVariant(), arg2 = QVariant(), arg3 = QVariant(), arg4 = QVariant(), arg5 = QVariant(), arg6 = QVariant(), arg7 = QVariant(), arg8 = QVariant()):
        '''QDBusMessage QDBusAbstractInterface.call(str method, QVariant arg1 = QVariant(), QVariant arg2 = QVariant(), QVariant arg3 = QVariant(), QVariant arg4 = QVariant(), QVariant arg5 = QVariant(), QVariant arg6 = QVariant(), QVariant arg7 = QVariant(), QVariant arg8 = QVariant())'''
        return QDBusMessage()
    def call(self, mode, method, arg1 = QVariant(), arg2 = QVariant(), arg3 = QVariant(), arg4 = QVariant(), arg5 = QVariant(), arg6 = QVariant(), arg7 = QVariant(), arg8 = QVariant()):
        '''QDBusMessage QDBusAbstractInterface.call(QDBus.CallMode mode, str method, QVariant arg1 = QVariant(), QVariant arg2 = QVariant(), QVariant arg3 = QVariant(), QVariant arg4 = QVariant(), QVariant arg5 = QVariant(), QVariant arg6 = QVariant(), QVariant arg7 = QVariant(), QVariant arg8 = QVariant())'''
        return QDBusMessage()
    def timeout(self):
        '''int QDBusAbstractInterface.timeout()'''
        return int()
    def setTimeout(self, timeout):
        '''void QDBusAbstractInterface.setTimeout(int timeout)'''
    def lastError(self):
        '''QDBusError QDBusAbstractInterface.lastError()'''
        return QDBusError()
    def interface(self):
        '''str QDBusAbstractInterface.interface()'''
        return str()
    def path(self):
        '''str QDBusAbstractInterface.path()'''
        return str()
    def service(self):
        '''str QDBusAbstractInterface.service()'''
        return str()
    def connection(self):
        '''QDBusConnection QDBusAbstractInterface.connection()'''
        return QDBusConnection()
    def isValid(self):
        '''bool QDBusAbstractInterface.isValid()'''
        return bool()


class QDBusArgument():
    """"""
    def __init__(self):
        '''void QDBusArgument.__init__()'''
    def __init__(self, other):
        '''void QDBusArgument.__init__(QDBusArgument other)'''
    def __init__(self, arg, id = None):
        '''void QDBusArgument.__init__(object arg, int id = QMetaType.Int)'''
    def endMapEntry(self):
        '''void QDBusArgument.endMapEntry()'''
    def beginMapEntry(self):
        '''void QDBusArgument.beginMapEntry()'''
    def endMap(self):
        '''void QDBusArgument.endMap()'''
    def beginMap(self, kid, vid):
        '''void QDBusArgument.beginMap(int kid, int vid)'''
    def endArray(self):
        '''void QDBusArgument.endArray()'''
    def beginArray(self, id):
        '''void QDBusArgument.beginArray(int id)'''
    def endStructure(self):
        '''void QDBusArgument.endStructure()'''
    def beginStructure(self):
        '''void QDBusArgument.beginStructure()'''
    def add(self, arg, id = None):
        ''' QDBusArgument.add(object arg, int id = QMetaType.Int)'''
        return ()


class QDBus():
    """"""
    # Enum QDBus.CallMode
    NoBlock = 0
    Block = 0
    BlockWithGui = 0
    AutoDetect = 0



class QDBusConnection():
    """"""
    # Enum QDBusConnection.ConnectionCapability
    UnixFileDescriptorPassing = 0

    # Enum QDBusConnection.UnregisterMode
    UnregisterNode = 0
    UnregisterTree = 0

    # Enum QDBusConnection.RegisterOption
    ExportAdaptors = 0
    ExportScriptableSlots = 0
    ExportScriptableSignals = 0
    ExportScriptableProperties = 0
    ExportScriptableInvokables = 0
    ExportScriptableContents = 0
    ExportNonScriptableSlots = 0
    ExportNonScriptableSignals = 0
    ExportNonScriptableProperties = 0
    ExportNonScriptableInvokables = 0
    ExportNonScriptableContents = 0
    ExportAllSlots = 0
    ExportAllSignals = 0
    ExportAllProperties = 0
    ExportAllInvokables = 0
    ExportAllContents = 0
    ExportAllSignal = 0
    ExportChildObjects = 0

    # Enum QDBusConnection.BusType
    SessionBus = 0
    SystemBus = 0
    ActivationBus = 0

    def __init__(self, name):
        '''void QDBusConnection.__init__(str name)'''
    def __init__(self, other):
        '''void QDBusConnection.__init__(QDBusConnection other)'''
    def sender(self):
        '''static QDBusConnection QDBusConnection.sender()'''
        return QDBusConnection()
    def systemBus(self):
        '''static QDBusConnection QDBusConnection.systemBus()'''
        return QDBusConnection()
    def sessionBus(self):
        '''static QDBusConnection QDBusConnection.sessionBus()'''
        return QDBusConnection()
    def localMachineId(self):
        '''static QByteArray QDBusConnection.localMachineId()'''
        return QByteArray()
    def disconnectFromPeer(self, name):
        '''static void QDBusConnection.disconnectFromPeer(str name)'''
    def disconnectFromBus(self, name):
        '''static void QDBusConnection.disconnectFromBus(str name)'''
    def connectToPeer(self, address, name):
        '''static QDBusConnection QDBusConnection.connectToPeer(str address, str name)'''
        return QDBusConnection()
    def connectToBus(self, type, name):
        '''static QDBusConnection QDBusConnection.connectToBus(QDBusConnection.BusType type, str name)'''
        return QDBusConnection()
    def connectToBus(self, address, name):
        '''static QDBusConnection QDBusConnection.connectToBus(str address, str name)'''
        return QDBusConnection()
    def interface(self):
        '''QDBusConnectionInterface QDBusConnection.interface()'''
        return QDBusConnectionInterface()
    def unregisterService(self, serviceName):
        '''bool QDBusConnection.unregisterService(str serviceName)'''
        return bool()
    def registerService(self, serviceName):
        '''bool QDBusConnection.registerService(str serviceName)'''
        return bool()
    def objectRegisteredAt(self, path):
        '''QObject QDBusConnection.objectRegisteredAt(str path)'''
        return QObject()
    def unregisterObject(self, path, mode = None):
        '''void QDBusConnection.unregisterObject(str path, QDBusConnection.UnregisterMode mode = QDBusConnection.UnregisterNode)'''
    def registerObject(self, path, object, options = None):
        '''bool QDBusConnection.registerObject(str path, QObject object, QDBusConnection.RegisterOptions options = QDBusConnection.ExportAdaptors)'''
        return bool()
    def registerObject(self, path, interface, object, options = None):
        '''bool QDBusConnection.registerObject(str path, str interface, QObject object, QDBusConnection.RegisterOptions options = QDBusConnection.ExportAdaptors)'''
        return bool()
    def disconnect(self, service, path, interface, name, slot):
        '''bool QDBusConnection.disconnect(str service, str path, str interface, str name, slot slot)'''
        return bool()
    def disconnect(self, service, path, interface, name, signature, slot):
        '''bool QDBusConnection.disconnect(str service, str path, str interface, str name, str signature, slot slot)'''
        return bool()
    def disconnect(self, service, path, interface, name, argumentMatch, signature, slot):
        '''bool QDBusConnection.disconnect(str service, str path, str interface, str name, list-of-str argumentMatch, str signature, slot slot)'''
        return bool()
    def connect(self, service, path, interface, name, slot):
        '''bool QDBusConnection.connect(str service, str path, str interface, str name, slot slot)'''
        return bool()
    def connect(self, service, path, interface, name, signature, slot):
        '''bool QDBusConnection.connect(str service, str path, str interface, str name, str signature, slot slot)'''
        return bool()
    def connect(self, service, path, interface, name, argumentMatch, signature, slot):
        '''bool QDBusConnection.connect(str service, str path, str interface, str name, list-of-str argumentMatch, str signature, slot slot)'''
        return bool()
    def asyncCall(self, message, timeout = None):
        '''QDBusPendingCall QDBusConnection.asyncCall(QDBusMessage message, int timeout = -1)'''
        return QDBusPendingCall()
    def call(self, message, mode = None, timeout = None):
        '''QDBusMessage QDBusConnection.call(QDBusMessage message, QDBus.CallMode mode = QDBus.Block, int timeout = -1)'''
        return QDBusMessage()
    def callWithCallback(self, message, returnMethod, errorMethod, timeout = None):
        '''bool QDBusConnection.callWithCallback(QDBusMessage message, slot returnMethod, slot errorMethod, int timeout = -1)'''
        return bool()
    def send(self, message):
        '''bool QDBusConnection.send(QDBusMessage message)'''
        return bool()
    def connectionCapabilities(self):
        '''QDBusConnection.ConnectionCapabilities QDBusConnection.connectionCapabilities()'''
        return QDBusConnection.ConnectionCapabilities()
    def name(self):
        '''str QDBusConnection.name()'''
        return str()
    def lastError(self):
        '''QDBusError QDBusConnection.lastError()'''
        return QDBusError()
    def baseService(self):
        '''str QDBusConnection.baseService()'''
        return str()
    def isConnected(self):
        '''bool QDBusConnection.isConnected()'''
        return bool()
    class RegisterOptions():
        """"""
        def __init__(self):
            '''QDBusConnection.RegisterOptions QDBusConnection.RegisterOptions.__init__()'''
            return QDBusConnection.RegisterOptions()
        def __init__(self):
            '''int QDBusConnection.RegisterOptions.__init__()'''
            return int()
        def __init__(self):
            '''void QDBusConnection.RegisterOptions.__init__()'''
        def __bool__(self):
            '''int QDBusConnection.RegisterOptions.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QDBusConnection.RegisterOptions.__ne__(QDBusConnection.RegisterOptions f)'''
            return bool()
        def __eq__(self, f):
            '''bool QDBusConnection.RegisterOptions.__eq__(QDBusConnection.RegisterOptions f)'''
            return bool()
        def __invert__(self):
            '''QDBusConnection.RegisterOptions QDBusConnection.RegisterOptions.__invert__()'''
            return QDBusConnection.RegisterOptions()
        def __and__(self, mask):
            '''QDBusConnection.RegisterOptions QDBusConnection.RegisterOptions.__and__(int mask)'''
            return QDBusConnection.RegisterOptions()
        def __xor__(self, f):
            '''QDBusConnection.RegisterOptions QDBusConnection.RegisterOptions.__xor__(QDBusConnection.RegisterOptions f)'''
            return QDBusConnection.RegisterOptions()
        def __xor__(self, f):
            '''QDBusConnection.RegisterOptions QDBusConnection.RegisterOptions.__xor__(int f)'''
            return QDBusConnection.RegisterOptions()
        def __or__(self, f):
            '''QDBusConnection.RegisterOptions QDBusConnection.RegisterOptions.__or__(QDBusConnection.RegisterOptions f)'''
            return QDBusConnection.RegisterOptions()
        def __or__(self, f):
            '''QDBusConnection.RegisterOptions QDBusConnection.RegisterOptions.__or__(int f)'''
            return QDBusConnection.RegisterOptions()
        def __int__(self):
            '''int QDBusConnection.RegisterOptions.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QDBusConnection.RegisterOptions QDBusConnection.RegisterOptions.__ixor__(QDBusConnection.RegisterOptions f)'''
            return QDBusConnection.RegisterOptions()
        def __ior__(self, f):
            '''QDBusConnection.RegisterOptions QDBusConnection.RegisterOptions.__ior__(QDBusConnection.RegisterOptions f)'''
            return QDBusConnection.RegisterOptions()
        def __iand__(self, mask):
            '''QDBusConnection.RegisterOptions QDBusConnection.RegisterOptions.__iand__(int mask)'''
            return QDBusConnection.RegisterOptions()
    class ConnectionCapabilities():
        """"""
        def __init__(self):
            '''QDBusConnection.ConnectionCapabilities QDBusConnection.ConnectionCapabilities.__init__()'''
            return QDBusConnection.ConnectionCapabilities()
        def __init__(self):
            '''int QDBusConnection.ConnectionCapabilities.__init__()'''
            return int()
        def __init__(self):
            '''void QDBusConnection.ConnectionCapabilities.__init__()'''
        def __bool__(self):
            '''int QDBusConnection.ConnectionCapabilities.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QDBusConnection.ConnectionCapabilities.__ne__(QDBusConnection.ConnectionCapabilities f)'''
            return bool()
        def __eq__(self, f):
            '''bool QDBusConnection.ConnectionCapabilities.__eq__(QDBusConnection.ConnectionCapabilities f)'''
            return bool()
        def __invert__(self):
            '''QDBusConnection.ConnectionCapabilities QDBusConnection.ConnectionCapabilities.__invert__()'''
            return QDBusConnection.ConnectionCapabilities()
        def __and__(self, mask):
            '''QDBusConnection.ConnectionCapabilities QDBusConnection.ConnectionCapabilities.__and__(int mask)'''
            return QDBusConnection.ConnectionCapabilities()
        def __xor__(self, f):
            '''QDBusConnection.ConnectionCapabilities QDBusConnection.ConnectionCapabilities.__xor__(QDBusConnection.ConnectionCapabilities f)'''
            return QDBusConnection.ConnectionCapabilities()
        def __xor__(self, f):
            '''QDBusConnection.ConnectionCapabilities QDBusConnection.ConnectionCapabilities.__xor__(int f)'''
            return QDBusConnection.ConnectionCapabilities()
        def __or__(self, f):
            '''QDBusConnection.ConnectionCapabilities QDBusConnection.ConnectionCapabilities.__or__(QDBusConnection.ConnectionCapabilities f)'''
            return QDBusConnection.ConnectionCapabilities()
        def __or__(self, f):
            '''QDBusConnection.ConnectionCapabilities QDBusConnection.ConnectionCapabilities.__or__(int f)'''
            return QDBusConnection.ConnectionCapabilities()
        def __int__(self):
            '''int QDBusConnection.ConnectionCapabilities.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QDBusConnection.ConnectionCapabilities QDBusConnection.ConnectionCapabilities.__ixor__(QDBusConnection.ConnectionCapabilities f)'''
            return QDBusConnection.ConnectionCapabilities()
        def __ior__(self, f):
            '''QDBusConnection.ConnectionCapabilities QDBusConnection.ConnectionCapabilities.__ior__(QDBusConnection.ConnectionCapabilities f)'''
            return QDBusConnection.ConnectionCapabilities()
        def __iand__(self, mask):
            '''QDBusConnection.ConnectionCapabilities QDBusConnection.ConnectionCapabilities.__iand__(int mask)'''
            return QDBusConnection.ConnectionCapabilities()


class QDBusConnectionInterface(QDBusAbstractInterface):
    """"""
    # Enum QDBusConnectionInterface.RegisterServiceReply
    ServiceNotRegistered = 0
    ServiceRegistered = 0
    ServiceQueued = 0

    # Enum QDBusConnectionInterface.ServiceReplacementOptions
    DontAllowReplacement = 0
    AllowReplacement = 0

    # Enum QDBusConnectionInterface.ServiceQueueOptions
    DontQueueService = 0
    QueueService = 0
    ReplaceExistingService = 0

    def disconnectNotify(self):
        '''QMetaMethod QDBusConnectionInterface.disconnectNotify()'''
        return QMetaMethod()
    def connectNotify(self):
        '''QMetaMethod QDBusConnectionInterface.connectNotify()'''
        return QMetaMethod()
    callWithCallbackFailed = pyqtSignal() # void callWithCallbackFailed(const QDBusErroramp;,const QDBusMessageamp;) - signal
    serviceUnregistered = pyqtSignal() # void serviceUnregistered(const QStringamp;) - signal
    serviceRegistered = pyqtSignal() # void serviceRegistered(const QStringamp;) - signal
    def startService(self, name):
        '''QDBusReply QDBusConnectionInterface.startService(str name)'''
        return QDBusReply()
    def serviceUid(self, serviceName):
        '''QDBusReply QDBusConnectionInterface.serviceUid(str serviceName)'''
        return QDBusReply()
    def servicePid(self, serviceName):
        '''QDBusReply QDBusConnectionInterface.servicePid(str serviceName)'''
        return QDBusReply()
    def registerService(self, serviceName, qoption = None, roption = None):
        '''QDBusReply QDBusConnectionInterface.registerService(str serviceName, QDBusConnectionInterface.ServiceQueueOptions qoption = QDBusConnectionInterface.DontQueueService, QDBusConnectionInterface.ServiceReplacementOptions roption = QDBusConnectionInterface.DontAllowReplacement)'''
        return QDBusReply()
    def unregisterService(self, serviceName):
        '''QDBusReply QDBusConnectionInterface.unregisterService(str serviceName)'''
        return QDBusReply()
    def serviceOwner(self, name):
        '''QDBusReply QDBusConnectionInterface.serviceOwner(str name)'''
        return QDBusReply()
    def isServiceRegistered(self, serviceName):
        '''QDBusReply QDBusConnectionInterface.isServiceRegistered(str serviceName)'''
        return QDBusReply()
    def registeredServiceNames(self):
        '''QDBusReply QDBusConnectionInterface.registeredServiceNames()'''
        return QDBusReply()


class QDBusError():
    """"""
    # Enum QDBusError.ErrorType
    NoError = 0
    Other = 0
    Failed = 0
    NoMemory = 0
    ServiceUnknown = 0
    NoReply = 0
    BadAddress = 0
    NotSupported = 0
    LimitsExceeded = 0
    AccessDenied = 0
    NoServer = 0
    Timeout = 0
    NoNetwork = 0
    AddressInUse = 0
    Disconnected = 0
    InvalidArgs = 0
    UnknownMethod = 0
    TimedOut = 0
    InvalidSignature = 0
    UnknownInterface = 0
    InternalError = 0
    UnknownObject = 0
    InvalidService = 0
    InvalidObjectPath = 0
    InvalidInterface = 0
    InvalidMember = 0
    UnknownProperty = 0
    PropertyReadOnly = 0

    def __init__(self, other):
        '''void QDBusError.__init__(QDBusError other)'''
    def errorString(self, error):
        '''static str QDBusError.errorString(QDBusError.ErrorType error)'''
        return str()
    def isValid(self):
        '''bool QDBusError.isValid()'''
        return bool()
    def message(self):
        '''str QDBusError.message()'''
        return str()
    def name(self):
        '''str QDBusError.name()'''
        return str()
    def type(self):
        '''QDBusError.ErrorType QDBusError.type()'''
        return QDBusError.ErrorType()


class QDBusObjectPath():
    """"""
    def __init__(self):
        '''void QDBusObjectPath.__init__()'''
    def __init__(self, objectPath):
        '''void QDBusObjectPath.__init__(str objectPath)'''
    def __init__(self):
        '''QDBusObjectPath QDBusObjectPath.__init__()'''
        return QDBusObjectPath()
    def __ge__(self, rhs):
        '''bool QDBusObjectPath.__ge__(QDBusObjectPath rhs)'''
        return bool()
    def __eq__(self, rhs):
        '''bool QDBusObjectPath.__eq__(QDBusObjectPath rhs)'''
        return bool()
    def __ne__(self, rhs):
        '''bool QDBusObjectPath.__ne__(QDBusObjectPath rhs)'''
        return bool()
    def __lt__(self, rhs):
        '''bool QDBusObjectPath.__lt__(QDBusObjectPath rhs)'''
        return bool()
    def __hash__(self):
        '''int QDBusObjectPath.__hash__()'''
        return int()
    def setPath(self, objectPath):
        '''void QDBusObjectPath.setPath(str objectPath)'''
    def path(self):
        '''str QDBusObjectPath.path()'''
        return str()


class QDBusSignature():
    """"""
    def __init__(self):
        '''void QDBusSignature.__init__()'''
    def __init__(self, dBusSignature):
        '''void QDBusSignature.__init__(str dBusSignature)'''
    def __init__(self):
        '''QDBusSignature QDBusSignature.__init__()'''
        return QDBusSignature()
    def __ge__(self, rhs):
        '''bool QDBusSignature.__ge__(QDBusSignature rhs)'''
        return bool()
    def __eq__(self, rhs):
        '''bool QDBusSignature.__eq__(QDBusSignature rhs)'''
        return bool()
    def __ne__(self, rhs):
        '''bool QDBusSignature.__ne__(QDBusSignature rhs)'''
        return bool()
    def __lt__(self, rhs):
        '''bool QDBusSignature.__lt__(QDBusSignature rhs)'''
        return bool()
    def __hash__(self):
        '''int QDBusSignature.__hash__()'''
        return int()
    def setSignature(self, dBusSignature):
        '''void QDBusSignature.setSignature(str dBusSignature)'''
    def signature(self):
        '''str QDBusSignature.signature()'''
        return str()


class QDBusVariant():
    """"""
    def __init__(self):
        '''void QDBusVariant.__init__()'''
    def __init__(self, dBusVariant):
        '''void QDBusVariant.__init__(QVariant dBusVariant)'''
    def __init__(self):
        '''QDBusVariant QDBusVariant.__init__()'''
        return QDBusVariant()
    def __ne__(self, v2):
        '''bool QDBusVariant.__ne__(QDBusVariant v2)'''
        return bool()
    def __eq__(self, v2):
        '''bool QDBusVariant.__eq__(QDBusVariant v2)'''
        return bool()
    def setVariant(self, dBusVariant):
        '''void QDBusVariant.setVariant(QVariant dBusVariant)'''
    def variant(self):
        '''QVariant QDBusVariant.variant()'''
        return QVariant()


class QDBusInterface(QDBusAbstractInterface):
    """"""
    def __init__(self, service, path, interface = str(), connection = None, parent = None):
        '''void QDBusInterface.__init__(str service, str path, str interface = str(), QDBusConnection connection = QDBusConnection.sessionBus(), QObject parent = None)'''


class QDBusMessage():
    """"""
    # Enum QDBusMessage.MessageType
    InvalidMessage = 0
    MethodCallMessage = 0
    ReplyMessage = 0
    ErrorMessage = 0
    SignalMessage = 0

    def __init__(self):
        '''void QDBusMessage.__init__()'''
    def __init__(self, other):
        '''void QDBusMessage.__init__(QDBusMessage other)'''
    def __lshift__(self, arg):
        '''QDBusMessage QDBusMessage.__lshift__(QVariant arg)'''
        return QDBusMessage()
    def arguments(self):
        '''list-of-QVariant QDBusMessage.arguments()'''
        return [QVariant()]
    def setArguments(self, arguments):
        '''void QDBusMessage.setArguments(list-of-QVariant arguments)'''
    def autoStartService(self):
        '''bool QDBusMessage.autoStartService()'''
        return bool()
    def setAutoStartService(self, enable):
        '''void QDBusMessage.setAutoStartService(bool enable)'''
    def isDelayedReply(self):
        '''bool QDBusMessage.isDelayedReply()'''
        return bool()
    def setDelayedReply(self, enable):
        '''void QDBusMessage.setDelayedReply(bool enable)'''
    def isReplyRequired(self):
        '''bool QDBusMessage.isReplyRequired()'''
        return bool()
    def signature(self):
        '''str QDBusMessage.signature()'''
        return str()
    def type(self):
        '''QDBusMessage.MessageType QDBusMessage.type()'''
        return QDBusMessage.MessageType()
    def errorMessage(self):
        '''str QDBusMessage.errorMessage()'''
        return str()
    def errorName(self):
        '''str QDBusMessage.errorName()'''
        return str()
    def member(self):
        '''str QDBusMessage.member()'''
        return str()
    def interface(self):
        '''str QDBusMessage.interface()'''
        return str()
    def path(self):
        '''str QDBusMessage.path()'''
        return str()
    def service(self):
        '''str QDBusMessage.service()'''
        return str()
    def createErrorReply(self, name, msg):
        '''QDBusMessage QDBusMessage.createErrorReply(str name, str msg)'''
        return QDBusMessage()
    def createErrorReply(self, error):
        '''QDBusMessage QDBusMessage.createErrorReply(QDBusError error)'''
        return QDBusMessage()
    def createErrorReply(self, type, msg):
        '''QDBusMessage QDBusMessage.createErrorReply(QDBusError.ErrorType type, str msg)'''
        return QDBusMessage()
    def createReply(self, arguments = None):
        '''QDBusMessage QDBusMessage.createReply(list-of-QVariant arguments = QListlt;QVariantgt;())'''
        return QDBusMessage()
    def createReply(self, argument):
        '''QDBusMessage QDBusMessage.createReply(QVariant argument)'''
        return QDBusMessage()
    def createError(self, name, msg):
        '''static QDBusMessage QDBusMessage.createError(str name, str msg)'''
        return QDBusMessage()
    def createError(self, error):
        '''static QDBusMessage QDBusMessage.createError(QDBusError error)'''
        return QDBusMessage()
    def createError(self, type, msg):
        '''static QDBusMessage QDBusMessage.createError(QDBusError.ErrorType type, str msg)'''
        return QDBusMessage()
    def createMethodCall(self, service, path, interface, method):
        '''static QDBusMessage QDBusMessage.createMethodCall(str service, str path, str interface, str method)'''
        return QDBusMessage()
    def createSignal(self, path, interface, name):
        '''static QDBusMessage QDBusMessage.createSignal(str path, str interface, str name)'''
        return QDBusMessage()


class QDBusPendingCall():
    """"""
    def __init__(self, other):
        '''void QDBusPendingCall.__init__(QDBusPendingCall other)'''
    def swap(self, other):
        '''void QDBusPendingCall.swap(QDBusPendingCall other)'''
    def fromCompletedCall(self, message):
        '''static QDBusPendingCall QDBusPendingCall.fromCompletedCall(QDBusMessage message)'''
        return QDBusPendingCall()
    def fromError(self, error):
        '''static QDBusPendingCall QDBusPendingCall.fromError(QDBusError error)'''
        return QDBusPendingCall()


class QDBusPendingCallWatcher(QObject, QDBusPendingCall):
    """"""
    def __init__(self, call, parent = None):
        '''void QDBusPendingCallWatcher.__init__(QDBusPendingCall call, QObject parent = None)'''
    finished = pyqtSignal() # void finished(QDBusPendingCallWatcher*) - signal
    def waitForFinished(self):
        '''void QDBusPendingCallWatcher.waitForFinished()'''
    def isFinished(self):
        '''bool QDBusPendingCallWatcher.isFinished()'''
        return bool()


class QDBusServiceWatcher(QObject):
    """"""
    # Enum QDBusServiceWatcher.WatchModeFlag
    WatchForRegistration = 0
    WatchForUnregistration = 0
    WatchForOwnerChange = 0

    def __init__(self, parent = None):
        '''void QDBusServiceWatcher.__init__(QObject parent = None)'''
    def __init__(self, service, connection, watchMode = None, parent = None):
        '''void QDBusServiceWatcher.__init__(str service, QDBusConnection connection, QDBusServiceWatcher.WatchMode watchMode = QDBusServiceWatcher.WatchForOwnerChange, QObject parent = None)'''
    serviceOwnerChanged = pyqtSignal() # void serviceOwnerChanged(const QStringamp;,const QStringamp;,const QStringamp;) - signal
    serviceUnregistered = pyqtSignal() # void serviceUnregistered(const QStringamp;) - signal
    serviceRegistered = pyqtSignal() # void serviceRegistered(const QStringamp;) - signal
    def setConnection(self, connection):
        '''void QDBusServiceWatcher.setConnection(QDBusConnection connection)'''
    def connection(self):
        '''QDBusConnection QDBusServiceWatcher.connection()'''
        return QDBusConnection()
    def setWatchMode(self, mode):
        '''void QDBusServiceWatcher.setWatchMode(QDBusServiceWatcher.WatchMode mode)'''
    def watchMode(self):
        '''QDBusServiceWatcher.WatchMode QDBusServiceWatcher.watchMode()'''
        return QDBusServiceWatcher.WatchMode()
    def removeWatchedService(self, service):
        '''bool QDBusServiceWatcher.removeWatchedService(str service)'''
        return bool()
    def addWatchedService(self, newService):
        '''void QDBusServiceWatcher.addWatchedService(str newService)'''
    def setWatchedServices(self, services):
        '''void QDBusServiceWatcher.setWatchedServices(list-of-str services)'''
    def watchedServices(self):
        '''list-of-str QDBusServiceWatcher.watchedServices()'''
        return [str()]
    class WatchMode():
        """"""
        def __init__(self):
            '''QDBusServiceWatcher.WatchMode QDBusServiceWatcher.WatchMode.__init__()'''
            return QDBusServiceWatcher.WatchMode()
        def __init__(self):
            '''int QDBusServiceWatcher.WatchMode.__init__()'''
            return int()
        def __init__(self):
            '''void QDBusServiceWatcher.WatchMode.__init__()'''
        def __bool__(self):
            '''int QDBusServiceWatcher.WatchMode.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QDBusServiceWatcher.WatchMode.__ne__(QDBusServiceWatcher.WatchMode f)'''
            return bool()
        def __eq__(self, f):
            '''bool QDBusServiceWatcher.WatchMode.__eq__(QDBusServiceWatcher.WatchMode f)'''
            return bool()
        def __invert__(self):
            '''QDBusServiceWatcher.WatchMode QDBusServiceWatcher.WatchMode.__invert__()'''
            return QDBusServiceWatcher.WatchMode()
        def __and__(self, mask):
            '''QDBusServiceWatcher.WatchMode QDBusServiceWatcher.WatchMode.__and__(int mask)'''
            return QDBusServiceWatcher.WatchMode()
        def __xor__(self, f):
            '''QDBusServiceWatcher.WatchMode QDBusServiceWatcher.WatchMode.__xor__(QDBusServiceWatcher.WatchMode f)'''
            return QDBusServiceWatcher.WatchMode()
        def __xor__(self, f):
            '''QDBusServiceWatcher.WatchMode QDBusServiceWatcher.WatchMode.__xor__(int f)'''
            return QDBusServiceWatcher.WatchMode()
        def __or__(self, f):
            '''QDBusServiceWatcher.WatchMode QDBusServiceWatcher.WatchMode.__or__(QDBusServiceWatcher.WatchMode f)'''
            return QDBusServiceWatcher.WatchMode()
        def __or__(self, f):
            '''QDBusServiceWatcher.WatchMode QDBusServiceWatcher.WatchMode.__or__(int f)'''
            return QDBusServiceWatcher.WatchMode()
        def __int__(self):
            '''int QDBusServiceWatcher.WatchMode.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QDBusServiceWatcher.WatchMode QDBusServiceWatcher.WatchMode.__ixor__(QDBusServiceWatcher.WatchMode f)'''
            return QDBusServiceWatcher.WatchMode()
        def __ior__(self, f):
            '''QDBusServiceWatcher.WatchMode QDBusServiceWatcher.WatchMode.__ior__(QDBusServiceWatcher.WatchMode f)'''
            return QDBusServiceWatcher.WatchMode()
        def __iand__(self, mask):
            '''QDBusServiceWatcher.WatchMode QDBusServiceWatcher.WatchMode.__iand__(int mask)'''
            return QDBusServiceWatcher.WatchMode()


class QDBusUnixFileDescriptor():
    """"""
    def __init__(self):
        '''void QDBusUnixFileDescriptor.__init__()'''
    def __init__(self, fileDescriptor):
        '''void QDBusUnixFileDescriptor.__init__(int fileDescriptor)'''
    def __init__(self, other):
        '''void QDBusUnixFileDescriptor.__init__(QDBusUnixFileDescriptor other)'''
    def swap(self, other):
        '''void QDBusUnixFileDescriptor.swap(QDBusUnixFileDescriptor other)'''
    def isSupported(self):
        '''static bool QDBusUnixFileDescriptor.isSupported()'''
        return bool()
    def setFileDescriptor(self, fileDescriptor):
        '''void QDBusUnixFileDescriptor.setFileDescriptor(int fileDescriptor)'''
    def fileDescriptor(self):
        '''int QDBusUnixFileDescriptor.fileDescriptor()'''
        return int()
    def isValid(self):
        '''bool QDBusUnixFileDescriptor.isValid()'''
        return bool()


class QDBusPendingReply(QDBusPendingCall):
    """"""
    def __init__(self):
        '''void QDBusPendingReply.__init__()'''
    def __init__(self, other):
        '''void QDBusPendingReply.__init__(QDBusPendingReply other)'''
    def __init__(self, call):
        '''void QDBusPendingReply.__init__(QDBusPendingCall call)'''
    def __init__(self, reply):
        '''void QDBusPendingReply.__init__(QDBusMessage reply)'''
    def value(self, type = None):
        '''object QDBusPendingReply.value(object type = None)'''
        return object()
    def waitForFinished(self):
        '''void QDBusPendingReply.waitForFinished()'''
    def reply(self):
        '''QDBusMessage QDBusPendingReply.reply()'''
        return QDBusMessage()
    def isValid(self):
        '''bool QDBusPendingReply.isValid()'''
        return bool()
    def isFinished(self):
        '''bool QDBusPendingReply.isFinished()'''
        return bool()
    def isError(self):
        '''bool QDBusPendingReply.isError()'''
        return bool()
    def error(self):
        '''QDBusError QDBusPendingReply.error()'''
        return QDBusError()
    def argumentAt(self, index):
        '''QVariant QDBusPendingReply.argumentAt(int index)'''
        return QVariant()


class QDBusReply():
    """"""
    def __init__(self, reply):
        '''void QDBusReply.__init__(QDBusMessage reply)'''
    def __init__(self, call):
        '''void QDBusReply.__init__(QDBusPendingCall call)'''
    def __init__(self, error):
        '''void QDBusReply.__init__(QDBusError error)'''
    def __init__(self, other):
        '''void QDBusReply.__init__(QDBusReply other)'''
    def value(self, type = None):
        '''object QDBusReply.value(object type = None)'''
        return object()
    def isValid(self):
        '''bool QDBusReply.isValid()'''
        return bool()
    def error(self):
        '''QDBusError QDBusReply.error()'''
        return QDBusError()





# AUTO-GENERATED FILE -- DO NOT EDIT


ACCESS_COPY = 3
ACCESS_READ = 1
ACCESS_WRITE = 2
ALLOCATIONGRANULARITY = 4096
MAP_ANON = 32
MAP_ANONYMOUS = 32
MAP_DENYWRITE = 2048
MAP_EXECUTABLE = 4096
MAP_PRIVATE = 2
MAP_SHARED = 1
PAGESIZE = 4096
PROT_EXEC = 4
PROT_READ = 1
PROT_WRITE = 2
__package__ = None

class error(EnvironmentError):

  pass

class mmap(object):
  """ Windows: mmap(fileno, length[, tagname[, access[, offset]]])
  
  Maps length bytes from the file specified by the file handle fileno,
  and returns a mmap object.  If length is larger than the current size
  of the file, the file is extended to contain length bytes.  If length
  is 0, the maximum length of the map is the current size of the file,
  except that if the file is empty Windows raises an exception (you cannot
  create an empty mapping on Windows).
  
  Unix: mmap(fileno, length[, flags[, prot[, access[, offset]]]])
  
  Maps length bytes from the file specified by the file descriptor fileno,
  and returns a mmap object.  If length is 0, the maximum length of the map
  will be the current size of the file when mmap is called.
  flags specifies the nature of the mapping. MAP_PRIVATE creates a
  private copy-on-write mapping, so changes to the contents of the mmap
  object will be private to this process, and MAP_SHARED creates a mapping
  that's shared with all other processes mapping the same areas of the file.
  The default value is MAP_SHARED.
  
  To map anonymous memory, pass -1 as the fileno (both versions). """

  def close(self):
    pass

  def find(self):
    pass

  def flush(self):
    pass

  def move(self):
    pass

  def read(self):
    pass

  def read_byte(self):
    pass

  def readline(self):
    pass

  def resize(self):
    pass

  def rfind(self):
    pass

  def seek(self):
    pass

  def size(self):
    pass

  def tell(self):
    pass

  def write(self):
    pass

  def write_byte(self):
    pass




class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass
class Foo: pass



class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

class PolkitQt():
    """"""
    class ActionButton(PolkitQt.Action):
        """"""
        def __init__(self, button, actionId = QString(), parent = None):
            '''void PolkitQt.ActionButton.__init__(QAbstractButton button, QString actionId = QString(), QObject parent = None)'''
        clicked = pyqtSignal() # void clicked(QAbstractButton *,bool = 0) - signal
        def activate(self):
            '''bool PolkitQt.ActionButton.activate()'''
            return bool()
        def button(self):
            '''QAbstractButton PolkitQt.ActionButton.button()'''
            return QAbstractButton()
        def setButton(self, button):
            '''void PolkitQt.ActionButton.setButton(QAbstractButton button)'''
    class Context(QObject):
        """"""
        def __init__(self):
            '''void PolkitQt.Context.__init__()'''
        consoleKitDBChanged = pyqtSignal() # void consoleKitDBChanged() - signal
        configChanged = pyqtSignal() # void configChanged() - signal
        def lastError(self):
            '''QString PolkitQt.Context.lastError()'''
            return QString()
        def hasError(self):
            '''bool PolkitQt.Context.hasError()'''
            return bool()
    class Auth():
        """"""
        # Enum PolkitQt.Auth.Result
        Unknown = 0
        Yes = 0
        AdminAuthOneShot = 0
        AdminAuth = 0
        AdminAuthKeepSession = 0
        AdminAuthKeepAlways = 0
        SelfAuthOneShot = 0
        SelfAuth = 0
        SelfAuthKeepSession = 0
        SelfAuthKeepAlways = 0
        No = 0
    
        def isCallerAuthorized(self, actionId, pid, revokeIfOneShot):
            '''static PolkitQt.Auth.Result PolkitQt.Auth.isCallerAuthorized(QString actionId, int pid, bool revokeIfOneShot)'''
            return PolkitQt.Auth.Result()
        def isCallerAuthorized(self, actionId, dbusName, revokeIfOneShot):
            '''static PolkitQt.Auth.Result PolkitQt.Auth.isCallerAuthorized(QString actionId, QString dbusName, bool revokeIfOneShot)'''
            return PolkitQt.Auth.Result()
        def obtainAuth(self, actionId, winId = 0, pid = None):
            '''static bool PolkitQt.Auth.obtainAuth(QString actionId, int winId = 0, int pid = QCoreApplication.applicationPid())'''
            return bool()
        def computeAndObtainAuth(self, actionId, winId = 0, pid = None):
            '''static bool PolkitQt.Auth.computeAndObtainAuth(QString actionId, int winId = 0, int pid = QCoreApplication.applicationPid())'''
            return bool()
    class ActionButtons(PolkitQt.ActionButton):
        """"""
        def __init__(self, buttons, actionId = QString(), parent = None):
            '''void PolkitQt.ActionButtons.__init__(list-of-QAbstractButton buttons, QString actionId = QString(), QObject parent = None)'''
        def removeButton(self, button):
            '''void PolkitQt.ActionButtons.removeButton(QAbstractButton button)'''
        def addButton(self, button):
            '''void PolkitQt.ActionButtons.addButton(QAbstractButton button)'''
        def buttons(self):
            '''list-of-QAbstractButton PolkitQt.ActionButtons.buttons()'''
            return [QAbstractButton()]
        def setButtons(self, buttons):
            '''void PolkitQt.ActionButtons.setButtons(list-of-QAbstractButton buttons)'''
    class Action(QAction):
        """"""
        def __init__(self, actionId = QString(), parent = None):
            '''void PolkitQt.Action.__init__(QString actionId = QString(), QObject parent = None)'''
        def is_(self, actionId):
            '''bool PolkitQt.Action.is_(QString actionId)'''
            return bool()
        def isAllowed(self):
            '''bool PolkitQt.Action.isAllowed()'''
            return bool()
        def targetPID(self):
            '''int PolkitQt.Action.targetPID()'''
            return int()
        def setTargetPID(self, pid):
            '''void PolkitQt.Action.setTargetPID(int pid)'''
        def yesIcon(self):
            '''QIcon PolkitQt.Action.yesIcon()'''
            return QIcon()
        def setYesIcon(self, icon):
            '''void PolkitQt.Action.setYesIcon(QIcon icon)'''
        def yesWhatsThis(self):
            '''QString PolkitQt.Action.yesWhatsThis()'''
            return QString()
        def setYesWhatsThis(self, whatsThis):
            '''void PolkitQt.Action.setYesWhatsThis(QString whatsThis)'''
        def yesToolTip(self):
            '''QString PolkitQt.Action.yesToolTip()'''
            return QString()
        def setYesToolTip(self, toolTip):
            '''void PolkitQt.Action.setYesToolTip(QString toolTip)'''
        def yesText(self):
            '''QString PolkitQt.Action.yesText()'''
            return QString()
        def setYesText(self, text):
            '''void PolkitQt.Action.setYesText(QString text)'''
        def yesEnabled(self):
            '''bool PolkitQt.Action.yesEnabled()'''
            return bool()
        def setYesEnabled(self, value):
            '''void PolkitQt.Action.setYesEnabled(bool value)'''
        def yesVisible(self):
            '''bool PolkitQt.Action.yesVisible()'''
            return bool()
        def setYesVisible(self, value):
            '''void PolkitQt.Action.setYesVisible(bool value)'''
        def authIcon(self):
            '''QIcon PolkitQt.Action.authIcon()'''
            return QIcon()
        def setAuthIcon(self, icon):
            '''void PolkitQt.Action.setAuthIcon(QIcon icon)'''
        def authWhatsThis(self):
            '''QString PolkitQt.Action.authWhatsThis()'''
            return QString()
        def setAuthWhatsThis(self, whatsThis):
            '''void PolkitQt.Action.setAuthWhatsThis(QString whatsThis)'''
        def authToolTip(self):
            '''QString PolkitQt.Action.authToolTip()'''
            return QString()
        def setAuthToolTip(self, toolTip):
            '''void PolkitQt.Action.setAuthToolTip(QString toolTip)'''
        def authText(self):
            '''QString PolkitQt.Action.authText()'''
            return QString()
        def setAuthText(self, text):
            '''void PolkitQt.Action.setAuthText(QString text)'''
        def authEnabled(self):
            '''bool PolkitQt.Action.authEnabled()'''
            return bool()
        def setAuthEnabled(self, value):
            '''void PolkitQt.Action.setAuthEnabled(bool value)'''
        def authVisible(self):
            '''bool PolkitQt.Action.authVisible()'''
            return bool()
        def setAuthVisible(self, value):
            '''void PolkitQt.Action.setAuthVisible(bool value)'''
        def noIcon(self):
            '''QIcon PolkitQt.Action.noIcon()'''
            return QIcon()
        def setNoIcon(self, icon):
            '''void PolkitQt.Action.setNoIcon(QIcon icon)'''
        def noWhatsThis(self):
            '''QString PolkitQt.Action.noWhatsThis()'''
            return QString()
        def setNoWhatsThis(self, whatsThis):
            '''void PolkitQt.Action.setNoWhatsThis(QString whatsThis)'''
        def noToolTip(self):
            '''QString PolkitQt.Action.noToolTip()'''
            return QString()
        def setNoToolTip(self, toolTip):
            '''void PolkitQt.Action.setNoToolTip(QString toolTip)'''
        def noText(self):
            '''QString PolkitQt.Action.noText()'''
            return QString()
        def setNoText(self, text):
            '''void PolkitQt.Action.setNoText(QString text)'''
        def noEnabled(self):
            '''bool PolkitQt.Action.noEnabled()'''
            return bool()
        def setNoEnabled(self, value):
            '''void PolkitQt.Action.setNoEnabled(bool value)'''
        def noVisible(self):
            '''bool PolkitQt.Action.noVisible()'''
            return bool()
        def setNoVisible(self, value):
            '''void PolkitQt.Action.setNoVisible(bool value)'''
        def selfBlockedIcon(self):
            '''QIcon PolkitQt.Action.selfBlockedIcon()'''
            return QIcon()
        def setSelfBlockedIcon(self, icon):
            '''void PolkitQt.Action.setSelfBlockedIcon(QIcon icon)'''
        def selfBlockedWhatsThis(self):
            '''QString PolkitQt.Action.selfBlockedWhatsThis()'''
            return QString()
        def setSelfBlockedWhatsThis(self, whatsThis):
            '''void PolkitQt.Action.setSelfBlockedWhatsThis(QString whatsThis)'''
        def selfBlockedToolTip(self):
            '''QString PolkitQt.Action.selfBlockedToolTip()'''
            return QString()
        def setSelfBlockedToolTip(self, toolTip):
            '''void PolkitQt.Action.setSelfBlockedToolTip(QString toolTip)'''
        def selfBlockedText(self):
            '''QString PolkitQt.Action.selfBlockedText()'''
            return QString()
        def setSelfBlockedText(self, text):
            '''void PolkitQt.Action.setSelfBlockedText(QString text)'''
        def selfBlockedEnabled(self):
            '''bool PolkitQt.Action.selfBlockedEnabled()'''
            return bool()
        def setSelfBlockedEnabled(self, value):
            '''void PolkitQt.Action.setSelfBlockedEnabled(bool value)'''
        def selfBlockedVisible(self):
            '''bool PolkitQt.Action.selfBlockedVisible()'''
            return bool()
        def setSelfBlockedVisible(self, value):
            '''void PolkitQt.Action.setSelfBlockedVisible(bool value)'''
        def setIcon(self, icon):
            '''void PolkitQt.Action.setIcon(QIcon icon)'''
        def setWhatsThis(self, whatsThis):
            '''void PolkitQt.Action.setWhatsThis(QString whatsThis)'''
        def setToolTip(self, toolTip):
            '''void PolkitQt.Action.setToolTip(QString toolTip)'''
        def setText(self, text):
            '''void PolkitQt.Action.setText(QString text)'''
        def masterEnabled(self):
            '''bool PolkitQt.Action.masterEnabled()'''
            return bool()
        def setMasterEnabled(self, value):
            '''void PolkitQt.Action.setMasterEnabled(bool value)'''
        def masterVisible(self):
            '''bool PolkitQt.Action.masterVisible()'''
            return bool()
        def setMasterVisible(self, value):
            '''void PolkitQt.Action.setMasterVisible(bool value)'''
        def actionId(self):
            '''QString PolkitQt.Action.actionId()'''
            return QString()
        def setPolkitAction(self, actionId = QString()):
            '''void PolkitQt.Action.setPolkitAction(QString actionId = QString())'''
        def revoke(self):
            '''void PolkitQt.Action.revoke()'''
        def setChecked(self, checked):
            '''void PolkitQt.Action.setChecked(bool checked)'''
        def activate(self, winId = 0):
            '''bool PolkitQt.Action.activate(int winId = 0)'''
            return bool()
        activated = pyqtSignal() # void activated() - signal
        dataChanged = pyqtSignal() # void dataChanged() - signal





#!/usr/bin/env python3

from contextlib import redirect_stdout
from io import StringIO
from sys import stdin, stdout, stderr
import sys
try:
    from pycodestyle import Checker, StyleGuide
except ImportError:
    try:
        from pep8 import Checker, StyleGuide
    except ImportError:
        Checker = None

while True:
    size = stdin.buffer.read(10)
    size = int(size)
    if not size > 0:
        continue
    buf = bytes()
    while len(buf) < size:
        buf += stdin.buffer.read(min(1024, size - len(buf)))
    lines = buf.decode("utf-8").splitlines()
    opts, text = lines[:3], [l + "\n" for l in lines[3:]]

    if Checker is not None:
        style_guide = StyleGuide()
        options = style_guide.options
        select = [x for x in opts[0].strip().split(',') if len(x) > 0]
        ignore = [x for x in opts[1].strip().split(',') if len(x) > 0]
        options.select = tuple(select)
        options.ignore = tuple(ignore)
        options.max_line_length = int(opts[2])
        stderr.flush()
        c = Checker(lines=text, options=options)
        output = StringIO()
        with redirect_stdout(output):
            # writes directly to stdout, so catch it ...
            c.check_all()
        output = output.getvalue()
        output = output[:2**15]

        stdout.write("{0:>10}".format(len(output)))
        stdout.write(output)
        stdout.flush()
    else:
        stderr.write("The `pycodestyle` (previously `pep8`) module is not installed.")
        stderr.flush()
        stdout.write("{0:>10}".format(0))
        stdout.flush()



# AUTO-GENERATED FILE -- DO NOT EDIT

""" Importing this module enables command line editing using GNU readline. """

__package__ = None

def add_history(string):
  """ add_history(string) -> None
  add a line to the history buffer """
  return None

def clear_history():
  """ clear_history() -> None
  Clear the current readline history. """
  return None

def get_begidx():
  """ get_begidx() -> int
  get the beginning index of the readline tab-completion scope """
  return 1

def get_completer():
  """ get_completer() -> function
  
  Returns current completer function. """
  return None

def get_completer_delims():
  """ get_completer_delims() -> string
  get the readline word delimiters for tab-completion """
  return ""

def get_completion_type():
  """ get_completion_type() -> int
  Get the type of completion being attempted. """
  return 1

def get_current_history_length():
  """ get_current_history_length() -> integer
  return the current (not the maximum) length of history. """
  return 1

def get_endidx():
  """ get_endidx() -> int
  get the ending index of the readline tab-completion scope """
  return 1

def get_history_item():
  """ get_history_item() -> string
  return the current contents of history item at index. """
  return ""

def get_history_length():
  """ get_history_length() -> int
  return the maximum number of items that will be written to
  the history file. """
  return 1

def get_line_buffer():
  """ get_line_buffer() -> string
  return the current contents of the line buffer. """
  return ""

def insert_text(string):
  """ insert_text(string) -> None
  Insert text into the command line. """
  return None

def parse_and_bind(string):
  """ parse_and_bind(string) -> None
  Parse and execute single line of a readline init file. """
  return None

def read_history_file(filename=None):
  """ read_history_file([filename]) -> None
  Load a readline history file.
  The default filename is ~/.history. """
  return None

def read_init_file(filename=None):
  """ read_init_file([filename]) -> None
  Parse a readline initialization file.
  The default filename is the last filename used. """
  return None

def redisplay():
  """ redisplay() -> None
  Change what's displayed on the screen to reflect the current
  contents of the line buffer. """
  return None

def remove_history_item(pos):
  """ remove_history_item(pos) -> None
  remove history item given by its position """
  return None

def replace_history_item(pos, line):
  """ replace_history_item(pos, line) -> None
  replaces history item given by its position with contents of line """
  return None

def set_completer(function=None):
  """ set_completer([function]) -> None
  Set or remove the completer function.
  The function is called as function(text, state),
  for state in 0, 1, 2, ..., until it returns a non-string.
  It should return the next possible completion starting with 'text'. """
  return None

def set_completer_delims(string):
  """ set_completer_delims(string) -> None
  set the readline word delimiters for tab-completion """
  return None

def set_completion_display_matches_hook(function=None):
  """ set_completion_display_matches_hook([function]) -> None
  Set or remove the completion display function.
  The function is called as
    function(substitution, [matches], longest_match_length)
  once each time matches need to be displayed. """
  return None

def set_history_length(length):
  """ set_history_length(length) -> None
  set the maximal number of items which will be written to
  the history file. A negative length is used to inhibit
  history truncation. """
  return None

def set_pre_input_hook(function=None):
  """ set_pre_input_hook([function]) -> None
  Set or remove the pre_input_hook function.
  The function is called with no arguments after the first prompt
  has been printed and just before readline starts reading input
  characters. """
  return None

def set_startup_hook(function=None):
  """ set_startup_hook([function]) -> None
  Set or remove the startup_hook function.
  The function is called with no arguments just
  before readline prints the first prompt. """
  return None

def write_history_file(filename=None):
  """ write_history_file([filename]) -> None
  Save a readline history file.
  The default filename is ~/.history. """
  return None




# AUTO-GENERATED FILE -- DO NOT EDIT


AFMT_AC3 = 1024
AFMT_A_LAW = 2
AFMT_IMA_ADPCM = 4
AFMT_MPEG = 512
AFMT_MU_LAW = 1
AFMT_QUERY = 0
AFMT_S16_BE = 32
AFMT_S16_LE = 16
AFMT_S16_NE = 16
AFMT_S8 = 64
AFMT_U16_BE = 256
AFMT_U16_LE = 128
AFMT_U8 = 8

class OSSAudioError(Exception):

  pass

SNDCTL_COPR_HALT = 3222553351
SNDCTL_COPR_LOAD = 3484435201
SNDCTL_COPR_RCODE = 3222553347
SNDCTL_COPR_RCVMSG = 2409906953
SNDCTL_COPR_RDATA = 3222553346
SNDCTL_COPR_RESET = 17152
SNDCTL_COPR_RUN = 3222553350
SNDCTL_COPR_SENDMSG = 3483648776
SNDCTL_COPR_WCODE = 1075069701
SNDCTL_COPR_WDATA = 1075069700
SNDCTL_DSP_BIND_CHANNEL = 3221508161
SNDCTL_DSP_CHANNELS = 3221508102
SNDCTL_DSP_GETBLKSIZE = 3221508100
SNDCTL_DSP_GETCAPS = 2147766287
SNDCTL_DSP_GETCHANNELMASK = 3221508160
SNDCTL_DSP_GETFMTS = 2147766283
SNDCTL_DSP_GETIPTR = 2148290577
SNDCTL_DSP_GETISPACE = 2148552717
SNDCTL_DSP_GETODELAY = 2147766295
SNDCTL_DSP_GETOPTR = 2148290578
SNDCTL_DSP_GETOSPACE = 2148552716
SNDCTL_DSP_GETSPDIF = 2147766339
SNDCTL_DSP_GETTRIGGER = 2147766288
SNDCTL_DSP_MAPINBUF = 2148552723
SNDCTL_DSP_MAPOUTBUF = 2148552724
SNDCTL_DSP_NONBLOCK = 20494
SNDCTL_DSP_POST = 20488
SNDCTL_DSP_PROFILE = 1074024471
SNDCTL_DSP_RESET = 20480
SNDCTL_DSP_SAMPLESIZE = 3221508101
SNDCTL_DSP_SETDUPLEX = 20502
SNDCTL_DSP_SETFMT = 3221508101
SNDCTL_DSP_SETFRAGMENT = 3221508106
SNDCTL_DSP_SETSPDIF = 1074024514
SNDCTL_DSP_SETSYNCRO = 20501
SNDCTL_DSP_SETTRIGGER = 1074024464
SNDCTL_DSP_SPEED = 3221508098
SNDCTL_DSP_STEREO = 3221508099
SNDCTL_DSP_SUBDIVIDE = 3221508105
SNDCTL_DSP_SYNC = 20481
SNDCTL_FM_4OP_ENABLE = 1074024719
SNDCTL_FM_LOAD_INSTR = 1076384007
SNDCTL_MIDI_INFO = 3228848396
SNDCTL_MIDI_MPUCMD = 3223416066
SNDCTL_MIDI_MPUMODE = 3221515521
SNDCTL_MIDI_PRETIME = 3221515520
SNDCTL_SEQ_CTRLRATE = 3221508355
SNDCTL_SEQ_GETINCOUNT = 2147766533
SNDCTL_SEQ_GETOUTCOUNT = 2147766532
SNDCTL_SEQ_GETTIME = 2147766547
SNDCTL_SEQ_NRMIDIS = 2147766539
SNDCTL_SEQ_NRSYNTHS = 2147766538
SNDCTL_SEQ_OUTOFBAND = 1074286866
SNDCTL_SEQ_PANIC = 20753
SNDCTL_SEQ_PERCMODE = 1074024710
SNDCTL_SEQ_RESET = 20736
SNDCTL_SEQ_RESETSAMPLES = 1074024713
SNDCTL_SEQ_SYNC = 20737
SNDCTL_SEQ_TESTMIDI = 1074024712
SNDCTL_SEQ_THRESHOLD = 1074024717
SNDCTL_SYNTH_CONTROL = 3483652373
SNDCTL_SYNTH_ID = 3230421268
SNDCTL_SYNTH_INFO = 3230421250
SNDCTL_SYNTH_MEMAVL = 3221508366
SNDCTL_SYNTH_REMOVESAMPLE = 3222032662
SNDCTL_TMR_CONTINUE = 21508
SNDCTL_TMR_METRONOME = 1074025479
SNDCTL_TMR_SELECT = 1074025480
SNDCTL_TMR_SOURCE = 3221509126
SNDCTL_TMR_START = 21506
SNDCTL_TMR_STOP = 21507
SNDCTL_TMR_TEMPO = 3221509125
SNDCTL_TMR_TIMEBASE = 3221509121
SOUND_MIXER_ALTPCM = 10
SOUND_MIXER_BASS = 1
SOUND_MIXER_CD = 8
SOUND_MIXER_DIGITAL1 = 17
SOUND_MIXER_DIGITAL2 = 18
SOUND_MIXER_DIGITAL3 = 19
SOUND_MIXER_IGAIN = 12
SOUND_MIXER_IMIX = 9
SOUND_MIXER_LINE = 6
SOUND_MIXER_LINE1 = 14
SOUND_MIXER_LINE2 = 15
SOUND_MIXER_LINE3 = 16
SOUND_MIXER_MIC = 7
SOUND_MIXER_MONITOR = 24
SOUND_MIXER_NRDEVICES = 25
SOUND_MIXER_OGAIN = 13
SOUND_MIXER_PCM = 4
SOUND_MIXER_PHONEIN = 20
SOUND_MIXER_PHONEOUT = 21
SOUND_MIXER_RADIO = 23
SOUND_MIXER_RECLEV = 11
SOUND_MIXER_SPEAKER = 5
SOUND_MIXER_SYNTH = 3
SOUND_MIXER_TREBLE = 2
SOUND_MIXER_VIDEO = 22
SOUND_MIXER_VOLUME = 0
__package__ = None
control_labels = []
control_names = []

error = OSSAudioError
def open():
  pass

def openmixer():
  pass




#!/usr/bin/env python

# SPDX-FileCopyrightText: 2014 Sven Brauch <svenbrauch@gmail.com>
# SPDX-License-Identifier: GPL-2.0-or-later

import importlib

modules = ["numpy", "numpy.ctypeslib",
           "numpy.lib.scimath", "numpy.fft", "numpy.linalg",
           "numpy.testing", "numpy.random"]

special_hints = {
    "array": { "returns": "ndarray()" }
}

import sys
sys.path.append("../introspection/")
import introspect
with open("../../documentation_files/numpy.py", 'w') as sys.stdout:
    sys.stdout.write("class getset_descriptor: pass\n")
    sys.stdout.write("class dictproxy: pass\n")
    sys.stdout.write("class member_descriptor: pass\n")

    for module in modules:
        dumper = introspect.ModuleDumper(importlib.import_module(module),
                                         startIndent=4*(module.count('.')),
                                         special_hints=special_hints)
        for index, component in enumerate(module.split('.')[1:]):
            sys.stdout.write((" "*index*4) + "class " + component + ":\n")
        dumper.dump()

    sys.stdout.write("fromfile = _fromfile\n")
    sys.stdout.write("frombuffer = _frombuffer\n")
    sys.stdout.write("fromstring = _fromstring\n")



# AUTO-GENERATED FILE -- DO NOT EDIT

""" This module provides an interface to the Posix calls for tty I/O control.
For a complete description of these calls, see the Posix or Unix manual
pages. It is only available for those Unix versions that support Posix
termios style tty I/O control.

All functions in this module take a file descriptor fd as their first
argument. This can be an integer file descriptor, such as returned by
sys.stdin.fileno(), or a file object, such as sys.stdin itself. """

B0 = 0
B110 = 3
B115200 = 4098
B1200 = 9
B134 = 4
B150 = 5
B1800 = 10
B19200 = 14
B200 = 6
B230400 = 4099
B2400 = 11
B300 = 7
B38400 = 15
B460800 = 4100
B4800 = 12
B50 = 1
B57600 = 4097
B600 = 8
B75 = 2
B9600 = 13
BRKINT = 2
BS0 = 0
BS1 = 8192
BSDLY = 8192
CBAUD = 4111
CBAUDEX = 4096
CDSUSP = 25
CEOF = 4
CEOL = 0
CEOT = 4
CERASE = 127
CFLUSH = 15
CIBAUD = 269418496
CINTR = 3
CKILL = 21
CLNEXT = 22
CLOCAL = 2048
CQUIT = 28
CR0 = 0
CR1 = 512
CR2 = 1024
CR3 = 1536
CRDLY = 1536
CREAD = 128
CRPRNT = 18
CRTSCTS = 2147483648
CS5 = 0
CS6 = 16
CS7 = 32
CS8 = 48
CSIZE = 48
CSTART = 17
CSTOP = 19
CSTOPB = 64
CSUSP = 26
CWERASE = 23
ECHO = 8
ECHOCTL = 512
ECHOE = 16
ECHOK = 32
ECHOKE = 2048
ECHONL = 64
ECHOPRT = 1024
EXTA = 14
EXTB = 15
FF0 = 0
FF1 = 32768
FFDLY = 32768
FIOASYNC = 21586
FIOCLEX = 21585
FIONBIO = 21537
FIONCLEX = 21584
FIONREAD = 21531
FLUSHO = 4096
HUPCL = 1024
ICANON = 2
ICRNL = 256
IEXTEN = 32768
IGNBRK = 1
IGNCR = 128
IGNPAR = 4
IMAXBEL = 8192
INLCR = 64
INPCK = 16
IOCSIZE_MASK = 1073676288
IOCSIZE_SHIFT = 16
ISIG = 1
ISTRIP = 32
IUCLC = 512
IXANY = 2048
IXOFF = 4096
IXON = 1024
NCC = 8
NCCS = 32
NL0 = 0
NL1 = 256
NLDLY = 256
NOFLSH = 128
N_MOUSE = 2
N_PPP = 3
N_SLIP = 1
N_STRIP = 4
N_TTY = 0
OCRNL = 8
OFDEL = 128
OFILL = 64
OLCUC = 2
ONLCR = 4
ONLRET = 32
ONOCR = 16
OPOST = 1
PARENB = 256
PARMRK = 8
PARODD = 512
PENDIN = 16384
TAB0 = 0
TAB1 = 2048
TAB2 = 4096
TAB3 = 6144
TABDLY = 6144
TCFLSH = 21515
TCGETA = 21509
TCGETS = 21505
TCIFLUSH = 0
TCIOFF = 2
TCIOFLUSH = 2
TCION = 3
TCOFLUSH = 1
TCOOFF = 0
TCOON = 1
TCSADRAIN = 1
TCSAFLUSH = 2
TCSANOW = 0
TCSBRK = 21513
TCSBRKP = 21541
TCSETA = 21510
TCSETAF = 21512
TCSETAW = 21511
TCSETS = 21506
TCSETSF = 21508
TCSETSW = 21507
TCXONC = 21514
TIOCCONS = 21533
TIOCEXCL = 21516
TIOCGETD = 21540
TIOCGICOUNT = 21597
TIOCGLCKTRMIOS = 21590
TIOCGPGRP = 21519
TIOCGSERIAL = 21534
TIOCGSOFTCAR = 21529
TIOCGWINSZ = 21523
TIOCINQ = 21531
TIOCLINUX = 21532
TIOCMBIC = 21527
TIOCMBIS = 21526
TIOCMGET = 21525
TIOCMIWAIT = 21596
TIOCMSET = 21528
TIOCM_CAR = 64
TIOCM_CD = 64
TIOCM_CTS = 32
TIOCM_DSR = 256
TIOCM_DTR = 2
TIOCM_LE = 1
TIOCM_RI = 128
TIOCM_RNG = 128
TIOCM_RTS = 4
TIOCM_SR = 16
TIOCM_ST = 8
TIOCNOTTY = 21538
TIOCNXCL = 21517
TIOCOUTQ = 21521
TIOCPKT = 21536
TIOCPKT_DATA = 0
TIOCPKT_DOSTOP = 32
TIOCPKT_FLUSHREAD = 1
TIOCPKT_FLUSHWRITE = 2
TIOCPKT_NOSTOP = 16
TIOCPKT_START = 8
TIOCPKT_STOP = 4
TIOCSCTTY = 21518
TIOCSERCONFIG = 21587
TIOCSERGETLSR = 21593
TIOCSERGETMULTI = 21594
TIOCSERGSTRUCT = 21592
TIOCSERGWILD = 21588
TIOCSERSETMULTI = 21595
TIOCSERSWILD = 21589
TIOCSER_TEMT = 1
TIOCSETD = 21539
TIOCSLCKTRMIOS = 21591
TIOCSPGRP = 21520
TIOCSSERIAL = 21535
TIOCSSOFTCAR = 21530
TIOCSTI = 21522
TIOCSWINSZ = 21524
TOSTOP = 256
VDISCARD = 13
VEOF = 4
VEOL = 11
VEOL2 = 16
VERASE = 2
VINTR = 0
VKILL = 3
VLNEXT = 15
VMIN = 6
VQUIT = 1
VREPRINT = 12
VSTART = 8
VSTOP = 9
VSUSP = 10
VSWTC = 7
VSWTCH = 7
VT0 = 0
VT1 = 16384
VTDLY = 16384
VTIME = 5
VWERASE = 14
XCASE = 4
XTABS = 6144
__package__ = None

class error(Exception):

  pass

def tcdrain(fd):
  """ tcdrain(fd) -> None
  
  Wait until all output written to file descriptor fd has been transmitted. """
  return None

def tcflow(fd, action):
  """ tcflow(fd, action) -> None
  
  Suspend or resume input or output on file descriptor fd.
  The action argument can be termios.TCOOFF to suspend output,
  termios.TCOON to restart output, termios.TCIOFF to suspend input,
  or termios.TCION to restart input. """
  return None

def tcflush(fd, queue):
  """ tcflush(fd, queue) -> None
  
  Discard queued data on file descriptor fd.
  The queue selector specifies which queue: termios.TCIFLUSH for the input
  queue, termios.TCOFLUSH for the output queue, or termios.TCIOFLUSH for
  both queues.  """
  return None

def tcgetattr(fd):
  """ tcgetattr(fd) -> list_of_attrs
  
  Get the tty attributes for file descriptor fd, as follows:
  [iflag, oflag, cflag, lflag, ispeed, ospeed, cc] where cc is a list
  of the tty special characters (each a string of length 1, except the items
  with indices VMIN and VTIME, which are integers when these fields are
  defined).  The interpretation of the flags and the speeds as well as the
  indexing in the cc array must be done using the symbolic constants defined
  in this module. """
  return []

def tcsendbreak(fd, duration):
  """ tcsendbreak(fd, duration) -> None
  
  Send a break on file descriptor fd.
  A zero duration sends a break for 0.25-0.5 seconds; a nonzero duration
  has a system dependent meaning. """
  return None

def tcsetattr(fd, when, attributes):
  """ tcsetattr(fd, when, attributes) -> None
  
  Set the tty attributes for file descriptor fd.
  The attributes to be set are taken from the attributes argument, which
  is a list like the one returned by tcgetattr(). The when argument
  determines when the attributes are changed: termios.TCSANOW to
  change immediately, termios.TCSADRAIN to change after transmitting all
  queued output, or termios.TCSAFLUSH to change after transmitting all
  queued output and discarding all queued input.  """
  return None




# AUTO-GENERATED FILE -- DO NOT EDIT

""" This module provides various functions to manipulate time values.

There are two standard representations of time.  One is the number
of seconds since the Epoch, in UTC (a.k.a. GMT).  It may be an integer
or a floating point number (to represent fractions of seconds).
The Epoch is system-defined; on Unix, it is generally January 1st, 1970.
The actual value can be retrieved by calling gmtime(0).

The other representation is a tuple of 9 integers giving local time.
The tuple items are:
  year (four digits, e.g. 1998)
  month (1-12)
  day (1-31)
  hours (0-23)
  minutes (0-59)
  seconds (0-59)
  weekday (0-6, Monday is 0)
  Julian day (day in the year, 1-366)
  DST (Daylight Savings Time) flag (-1, 0 or 1)
If the DST flag is 0, the time is given in the regular time zone;
if it is 1, the time is given in the DST time zone;
if it is -1, mktime() should guess based on the date and time.

Variables:

timezone -- difference in seconds between UTC and local standard time
altzone -- difference in  seconds between UTC and local DST time
daylight -- whether local time should reflect DST
tzname -- tuple of (standard time zone name, DST time zone name)

Functions:

time() -- return current time in seconds since the Epoch as a float
clock() -- return CPU time since process start as a float
sleep() -- delay for a number of seconds given as a float
gmtime() -- convert seconds since Epoch to UTC tuple
localtime() -- convert seconds since Epoch to local time tuple
asctime() -- convert time tuple to string
ctime() -- convert time in seconds to string
mktime() -- convert local time tuple to seconds since Epoch
strftime() -- convert time tuple to string according to format specification
strptime() -- parse string to time tuple according to format specification
tzset() -- change the local timezone """

__package__ = None
accept2dyear = 1
altzone = -7200

def asctime(tuple=None):
  """ asctime([tuple]) -> string
  
  Convert a time tuple to a string, e.g. 'Sat Jun 06 16:26:11 1998'.
  When the time tuple is not present, current time as returned by localtime()
  is used. """
  return ""

def clock():
  """ clock() -> floating point number
  
  Return the CPU time or real time since the start of the process or since
  the first call to clock().  This has as much precision as the system
  records. """
  return 1

def ctime(seconds):
  """ ctime(seconds) -> string
  
  Convert a time in seconds since the Epoch to a string in local time.
  This is equivalent to asctime(localtime(seconds)). When the time tuple is
  not present, current time as returned by localtime() is used. """
  return ""

daylight = 1

def gmtime(seconds=None):
  """ gmtime([seconds]) -> (tm_year, tm_mon, tm_mday, tm_hour, tm_min,
                         tm_sec, tm_wday, tm_yday, tm_isdst)
  
  Convert seconds since the Epoch to a time tuple expressing UTC (a.k.a.
  GMT).  When 'seconds' is not passed in, convert the current time instead. """
  return (None, None, None, None, None, None, None, None, None)

def localtime(seconds=None):
  """ localtime([seconds]) -> (tm_year,tm_mon,tm_mday,tm_hour,tm_min,
                            tm_sec,tm_wday,tm_yday,tm_isdst)
  
  Convert seconds since the Epoch to a time tuple expressing local time.
  When 'seconds' is not passed in, convert the current time instead. """
  return (None, None, None, None, None, None, None, None, None)

def mktime(tuple):
  """ mktime(tuple) -> floating point number
  
  Convert a time tuple in local time to seconds since the Epoch. """
  return 1

def sleep(seconds):
  """ sleep(seconds)
  
  Delay execution for a given number of seconds.  The argument may be
  a floating point number for subsecond precision. """
  pass

def strftime(format, tuple=None):
  """ strftime(format[, tuple]) -> string
  
  Convert a time tuple to a string according to a format specification.
  See the library reference manual for formatting codes. When the time tuple
  is not present, current time as returned by localtime() is used. """
  return ""

def strptime(string, format):
  """ strptime(string, format) -> struct_time
  
  Parse a string to a time tuple according to a format specification.
  See the library reference manual for formatting codes (same as strftime()). """
  return ""

class struct_time(object):
  """ The time value as returned by gmtime(), localtime(), and strptime(), and
   accepted by asctime(), mktime() and strftime().  May be considered as a
   sequence of 9 integers.
  
   Note that several fields' values are not the same as those defined by
   the C language standard for struct tm.  For example, the value of the
   field tm_year is the actual year, not year - 1900.  See individual
   fields' descriptions for details. """

  n_fields = 9
  n_sequence_fields = 9
  n_unnamed_fields = 0
  tm_hour = None
  tm_isdst = None
  tm_mday = None
  tm_min = None
  tm_mon = None
  tm_sec = None
  tm_wday = None
  tm_yday = None
  tm_year = None

def time():
  """ time() -> floating point number
  
  Return the current time in seconds since the Epoch.
  Fractions of a second may be present if the system clock provides them. """
  return 1

timezone = -3600
tzname = ()

def tzset():
  """ tzset()
  
  Initialize, or reinitialize, the local timezone to the value stored in
  os.environ['TZ']. The TZ environment variable should be specified in
  standard Unix timezone format as documented in the tzset man page
  (eg. 'US/Eastern', 'Europe/Amsterdam'). Unknown timezones will silently
  fall back to UTC. If the TZ environment variable is not set, the local
  timezone is set to the systems best guess of wallclock time.
  Changing the TZ environment variable without calling tzset *may* change
  the local timezone used by methods such as localtime, but this behaviour
  should not be relied on. """
  pass




#!/usr/bin/env python2.7
# This file is part of KDevelop
# SPDX-FileCopyrightText: 2011 Victor Varvariuc <victor.varvariuc@gmail.com>
# SPDX-FileCopyrightText: 2011 Sven Brauch <svenbrauch@googlemail.com>

import os, sys, subprocess
from xml.dom import minidom, NotFoundErr

import sipconfig
from PyQt4 import pyqtconfig

config = pyqtconfig.Configuration() # Get the PyQt configuration information.

def convertSipToXML(inFilePath, outFilePath):
    if not os.path.exists(outFilePath):
        command = [config.sip_bin, '-m', outFilePath, '-I', config.pyqt_sip_dir, '-I', config.pyqt_sip_dir+'/python3-PyKDE4']
        command.extend(config.pyqt_sip_flags.split())
        command.append(inFilePath)

        print('\nConverting sip to xml:\n%s' % ' '.join(command))
        try:
            print subprocess.check_output(command, stderr = subprocess.STDOUT)
        except subprocess.CalledProcessError as e:
            print('There was an error when running the command:')
            print(e.output)

        print('Opening and parsing XML document...')
        # replace the invalid "&"s which are used by pykde to indicate shortcuts
        # they would need to be escaped, but oh well
        f = open(outFilePath, 'r')
        data = f.read()
        f.close()
        data = data.replace('&', '')
        data = data.replace('("', '')
        data = data.replace('")', '')
        data = data.replace('""', '"')
        f = open(outFilePath, 'w')
        f.write(data)
        f.close()
    xmlDoc = minidom.parse(outFilePath)

    module = xmlDoc.firstChild
    assert module.nodeName == 'Module'
    moduleName = module.attributes['name'].value
    print('Module name: %s' % moduleName)

    def setIds(node):
        '''Set `name` attribute as id to be able to do node.getElementById('element_id')'''
        for node in node.childNodes:
            if node.nodeType == node.ELEMENT_NODE: # only element nodes
                try:
                    node.setIdAttribute('name')
                except NotFoundErr:
                    pass
                setIds(node)

    print('Setting IDs...')
    setIds(module) # recursively set IDs

    print('Looking for child classes...')
    childClasses = {}
    for node in module.childNodes:
        # skip non element nodes
        if node.nodeType == node.ELEMENT_NODE and node.nodeName == 'Class':
            name = node.attributes['name'].value
            if name.count('.') >= 1:
                childClasses[name] = node

    print('Reparenting classes...')
    for name, node in childClasses.iteritems():
        parentClassNode = xmlDoc
        parentClassNode = xmlDoc.getElementById(name.split('.')[0])
        for component in name.split('.')[1:-1]:
            previous = parentClassNode
            parentClassNode = xmlDoc.createElement("Class")
            parentClassNode.setAttribute("name", component)
            parentClassNode.setAttribute("convert", "1")
            previous.appendChild(parentClassNode)
            print "new class:", component
        node.setAttribute("name", name.split('.')[-1])
        parentClassNode.appendChild(node)

    print('Saving changes...')
    with open(outFilePath, 'w') as f:
        xmlDoc.writexml(f)


sipDir = config.pyqt_sip_dir
if not os.path.isdir(sipDir):
    print('Could not find sip direcotry: %s' % sipDir)
    print('Looks like package "python-qt-dev" is not installed.')
    sys.exit()

modules = sys.argv[1:] # ['QtGui.xml', 'QtCore.xml'] # files to convert

for moduleName in modules:
    sipFilePath = os.path.join(sipDir, moduleName, moduleName.split('/')[-1] + 'mod.sip')
    xmlFilePath = moduleName + '.xml'
    if os.path.isfile(sipFilePath) or os.path.exists(xmlFilePath.split('/')[-1]):
        convertSipToXML(sipFilePath, xmlFilePath.split('/')[-1])
    else:
        print('Input sip file does not exist: %s' % sipFilePath)
